@@ -52,7 +52,6 @@ package com.openexchange.authentication.imap.impl;
 import static com.openexchange.authentication.LoginExceptionCodes.INVALID_CREDENTIALS_MISSING_CONTEXT_MAPPING;
 import static com.openexchange.authentication.LoginExceptionCodes.INVALID_CREDENTIALS_MISSING_USER_MAPPING;
 import static com.openexchange.authentication.LoginExceptionCodes.UNKNOWN;
-import java.io.UnsupportedEncodingException;
 import java.util.Properties;
 import java.util.concurrent.TimeUnit;
 import javax.mail.AuthenticationFailedException;
@@ -77,6 +76,7 @@ import com.openexchange.groupware.contexts.impl.ContextStorage;
 import com.openexchange.java.Strings;
 import com.openexchange.mail.api.MailConfig.LoginSource;
 import com.openexchange.mail.config.MailProperties;
+import com.openexchange.mail.mime.MimeDefaultSession;
 import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.mailaccount.MailAccountStorageService;
 import com.openexchange.net.ssl.SSLSocketFactoryProvider;
@@ -150,16 +150,6 @@ public class IMAPAuthentication implements AuthenticationService {
                 throw LoginExceptionCodes.INVALID_CREDENTIALS.create();
             }
 
-            if (props.get(PropertyNames.IMAPAUTHENC.name) != null) {
-                String authenc = (String) props.get(PropertyNames.IMAPAUTHENC.name);
-                try {
-                    password = new String(password.getBytes(authenc), CHARENC_ISO8859);
-                } catch (UnsupportedEncodingException e) {
-                    LOG.error("", e);
-                    throw LoginExceptionCodes.COMMUNICATION.create(e);
-                }
-            }
-
             String imaptimeout = "4000";
             if (props.get(PropertyNames.IMAP_TIMEOUT.name) != null) {
                 imaptimeout = (String) props.get(PropertyNames.IMAP_TIMEOUT.name);
@@ -170,7 +160,7 @@ public class IMAPAuthentication implements AuthenticationService {
                 connectiontimeout = (String) props.get(PropertyNames.IMAP_CONNECTIONTIMEOUT.name);
             }
 
-            final Properties imapprops = new Properties();
+            final Properties imapprops = MimeDefaultSession.getDefaultMailProperties();
             imapprops.put("mail.imap.connectiontimeout", connectiontimeout);
             imapprops.put("mail.imap.timeout", imaptimeout);
 
@@ -240,7 +230,7 @@ public class IMAPAuthentication implements AuthenticationService {
 	                UserService userService = services.getService(UserService.class);
 	                try {
 	                    userId = userService.getUserId(userInfo, ctx);
-	                } catch (final OXException e) {
+	                } catch (OXException e) {
 	                    throw INVALID_CREDENTIALS_MISSING_USER_MAPPING.create(loginInfo.getUsername());
 	                }
 	            }
@@ -347,6 +337,16 @@ public class IMAPAuthentication implements AuthenticationService {
                 // Security.setProperty("ssl.SocketFactory.provider", socketFactoryClass);
             }
 
+            {
+                Object value = props.get(PropertyNames.IMAPAUTHENC.name);
+                if (value != null) {
+                    String authenc = (String) value;
+                    if (Strings.isNotEmpty(authenc)) {
+                        imapprops.put("mail.imap.login.encoding", authenc.trim());
+                    }
+                }
+            }
+
             Store imapconnection = null;
             try {
                 Session session = Session.getInstance(imapprops, null);
